#!/usr/bin/env node

/**
 * @file Build this project.
 */

var uiContrib = require('apeman-tmpl-contrib-official/lib/ui_contrib'),
    path = require('path'),
    glob = require('glob'),
    async = require('async'),
    dist = require('../dist');

var basedir = path.resolve(__dirname, '..');
process.chdir(basedir);

var pkg = require('../package.json');

var noop = function () {
};
var context = {
    logger: {
        debug: noop,
        info: noop
    }
};

async.series([
    function renderProject(callback) {
        uiContrib.render({
            pkg: pkg,
            ignore: [],
            year: new Date().getFullYear(),
            signature: require('../.signature'),
            dependencies: {
                'angular': '~1.4.3'
            },
            get docs() {
                var docs = {};
                glob.sync('assets/docs/**/*.md', {cwd: basedir}).filter(function (filename) {
                    return path.basename(filename) !== 'index.md';
                }).forEach(function (filename) {
                    docs[path.basename(filename, '.md')] = filename;
                });
                return docs;
            }
        }, callback);
    },
    function buildDependencies(callback) {
        async.eachSeries([
            require('apeman-ui-contrib-angular-objecting')
        ], function (dist, callback) {
            async.series([
                dist.bind(dist, context, {dest: 'assets/test/dependencies'}),
                dist.bind(dist, context, {dest: 'docs/demo'})
            ], callback);
        }, callback);
    },
    function generateDemo(callback) {
        dist(context, [], {
            dest: basedir + '/docs/demo'
        }, callback);
    },
    function generateDist(callback) {
        dist(context, [], {
            dest: basedir + '/assets/dist'
        }, callback);
    }

], function (err) {
    if (err) {
        console.error(err);
    }
});
